⇐ go back

### Font license info

Font Awesome

Copyright (C) 2016 by Dave Gandy

Author: Dave Gandy
License: SIL (http://scripts.sil.org/OFL)
Homepage: http://fortawesome.github.com/Font-Awesome/

Entypo

Copyright (C) 2012 by Daniel Bruce

Author: Daniel Bruce
License: SIL (http://scripts.sil.org/OFL)
Homepage: http://www.entypo.com

Modern Pictograms

Copyright (c) 2012 by John Caserta. All rights reserved.

Author: John Caserta
License: SIL (http://scripts.sil.org/OFL)
Homepage: http://thedesignoffice.org/project/modern-pictograms/

Elusive

Copyright (C) 2013 by Aristeides Stathopoulos

Author: Aristeides Stathopoulos
License: SIL (http://scripts.sil.org/OFL)
Homepage: http://aristeides.com/

Iconic

Copyright (C) 2012 by P.J. Onori

Author: P.J. Onori
License: SIL (http://scripts.sil.org/OFL)
Homepage: http://somerandomdude.com/work/iconic/

### Icon license info

Icons made by Freepik, Creaticca Creative Agency, Pixel perfect (Flaticon License) and Google (License CC 3.0 BY) from www.flaticon.com